usage: create_cli_help.py install [-h] [-p PARAMETER PARAMETER] [--max-version MAX_VERSION] [-r] [-g]

### options:
- `-h, --help`: show this help message and exit
- `-p PARAMETER PARAMETER, --parameter PARAMETER PARAMETER`
- `Assign variable for running SQL deltas. Format is name value.`
- `--max-version MAX_VERSION`
- `maximum version to install`
- `-r, --roles`: Create roles
- `-g, --grant`: Grant permissions to roles
